@@ -229,7 +229,7 @@ impl TryFrom<Vec<u8>> for structs::TinkoffApiKey{
     fn try_from(bytes: Vec<u8>) -> Result<Self, Self::Error> {
         let mut dst = [0u8; 8];
         dst.clone_from_slice(&bytes[0..8]);
-        let time: f64 = f64::from_be_bytes(dst);
+        let time: i64 = i64::from_be_bytes(dst);
         let mut str_ends: usize = 8;
         for (nom, char) in bytes[8..].iter().enumerate(){
             str_ends = nom+8;
